NetDumplings
============

NetDumplings helps you build your own computer network visualizations.  It lets
you sniff your network for interesting packets and display the results in any
way you please.  What NetDumplings listens for -- and how that information is
displayed -- is up to you.

NetDumplings requires Python 3.5.

NetDumplings can be installed with ``pip install netdumplings`` (you may want
to do that in a `virtual environment`_).

Complete documentation is available on `Read the Docs`_.

For an example of a 3D browser-based network visualization using NetDumplings,
see `packscape`_.

.. _Read the Docs: https://netdumplings.readthedocs.org/
.. _scapy-python3: https://github.com/phaethon/scapy
.. _virtual environment: http://docs.python-guide.org/en/latest/dev/virtualenvs/
.. _websockets: https://github.com/aaugustin/websockets
.. _packscape: https://github.com/mjoblin/packscape
